<?php

namespace App\Http\Controllers;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Response;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use Str;
Use Hash;
use Auth;
use App\Models\User;
use Carbon\Carbon;


class AdminUsersController extends Controller
{
    //
    public function ManageAdminUsers(Request $request){
        //dd(Auth::user());
        if(Auth::user()->id != ''){
            $data = User::orderBy('id','DESC')->paginate(10);

            return view('admin.adminuser',[
                'title' => 'Manage Admin Users: RIMS Admin Panel',
                'pageheader' => 'Manage Admin Users',
                'subheader' => 'Add, update admin users ',
                'data_count' => $data->count(),
                'data' => $data,
            ]);
        }

    }


    public function showAdminForm(Request $request){
        //dd(Auth::user());       
        return view('admin.addadmin',[
            'title' => 'Add Admin User: RIMS Admin Panel',
            'pageheader' => 'Add New Admin User',
            'subheader' => '',
        ]);
    }


    public function StoreNewAdminUsers(Request $request){
        //dd(Auth::user());   
        //dd($request->all());
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'emailId' => 'required',
            'emailId' => 'required|email|unique:users,email',
            'Designation' => 'required',
            'roles' => 'required',
            //'password' => 'required|confirmed|min:6',            
            'password' => 'min:6|required_with:password_confirmation|same:password',
        ],
        $messages = [
            'name.required' => 'Full name is required!',
            'emailId.required' => 'Valid email address is required!',
            'emailId.unique' => 'Email id already exists!',
            //'Designation.required' => ':attribute is required.',
            //'roles.required' =>  ':attribute is required.',
            'roles.required' =>  'Role is required.',
            'Designation.required' => 'Designation is required.',
            'password.required' =>  'Password is required.',            
        ]);

        
        if ($validator->fails()) {            
            return Redirect::back()->withErrors($validator)->withInput();
        }else{

            $user = new User;
            $input = $request->all();

            $user->name              = $request->input('name');
            $user->email             = $request->input('emailId');
            $user->mobile            = $request->input('mobileno');
            $user->designation       = $request->input('Designation');
            $user->role              = $request->input('roles');
            $user->status            = '1';
            $user->password          = Hash::make($request->newPassword);
            $user->created_at        = Carbon::now();
            //dd($user);
            
            $user->save();
            return redirect()->back()->with('success','Admin User Added Successfully');
        }       

    }


    
    public function ViewAdminUsers($id, Request $request){
        //dd($id);
        $data = User::where('id', $id)->first();
        return view('admin.edituser',[
            'title' => 'Update Admin User: RIMS Admin Panel',
            'pageheader' => 'Update Admin User Detail',
            'subheader' => '',
            'data'      => $data
        ]);
    }


    public function UpdateAdminUsers($id, Request $request){
        // $data = User::where('id', $id)->first();
        // dd($request->all(), $data);

        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'emailId' => 'required',
            'emailId' => 'required|email|unique:users,email,'.$id,
            'Designation' => 'required',
            'roles' => 'required',
            //'password' => 'required|confirmed|min:6',            
            //'password' => 'min:6|required_with:password_confirmation|same:password',
        ],
        $messages = [
            'name.required' => 'Full name is required!',
            'emailId.required' => 'Valid email address is required!',
            'emailId.unique' => 'Email id already exists!',
            //'Designation.required' => ':attribute is required.',
            //'roles.required' =>  ':attribute is required.',
            'roles.required' =>  'Role is required.',
            'Designation.required' => 'Designation is required.',
            //'password.required' =>  'Password is required.',            
        ]);

        
        if ($validator->fails()) {            
            return Redirect::back()->withErrors($validator)->withInput();
        }else{

            $user = User::find($id);
 
            $user->name              = $request->input('name');
            $user->email             = $request->input('emailId');
            $user->mobile            = $request->input('mobileno');
            $user->designation       = $request->input('Designation');
            $user->role              = $request->input('roles');
            $user->status          = $request->input('status');            
            $user->updated_at	     = Carbon::now();
            //dd($user);

            $user->save();

            // $data = User::orderBy('id','DESC')->paginate(10);
            //$message = "Profile updated successfully";

            // return view('admin.adminuser',[
            //     'title' => 'Manage Admin Users: RIMS Admin Panel',
            //     'pageheader' => 'Manage Admin Users',
            //     'subheader' => 'Add, update admin users ',
            //     'data_count' => $data->count(),
            //     'data' => $data,
            //     'success' => $message
            // ]);            

            return redirect()->action([AdminUsersController::class, 'ManageAdminUsers'])->with('success','Profile updated successfully');
            
        } 

    }

    public function DeleteAdminUsers($id, Request $request){
        $user = User::find($id);
        $user->delete();
        return redirect()->back()->with('success','Admin User Deleted Successfully');
    }


     public function ChangePassword($id, Request $request){
        $user = User::where('id',$id)->first();
        return view('admin.changepassword',[
            'title' => 'Change Admin Password: RIMS Admin Panel',
            'pageheader' => 'Change Admin Password',
            'subheader' => '',
            'data'      => $user ?? []
        ]);
     } 


     public function UpdatePassword($id, Request $request){

        // $data = User::where('id', $id)->first();
        // dd($request->all(), $data);

        $validator = Validator::make($request->all(), [                        
            'password' => 'min:6|required_with:password_confirmation|same:password',
        ],
        $messages = [
            'password.required' =>  'Password is required.',            
        ]);

        
        if ($validator->fails()) {            
            return Redirect::back()->withErrors($validator)->withInput();
        }else{

            $user = User::find($id);
            //$input = $request->all();
            
            $user->password          = Hash::make($request->newPassword);
            $user->updated_at        = Carbon::now();
            //dd($user);            
            $user->save();
            return redirect()->action([AdminUsersController::class, 'ManageAdminUsers'])->with('success','Password Updated Successfully');
            
        } 

     }

}
