<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Response;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use Str;
Use Hash;
use Auth;
use App\Models\User;
use App\Models\Parentmenu;
use Carbon\Carbon;

class ParentmenuController extends Controller
{
    /**
     * Display a listing of the resource.
     */

    public function index()
    {
        //
        $data       = Parentmenu::orderBy('id','DESC')->paginate(50);
        $data_menu  = Parentmenu::where('menu_type','parent')->orderBy('id','DESC')->get();
        //dd($data_menu);
        return view('menu.parentmenu',[
            'title' => 'Parent Menu: RIMS Admin Panel',
            'pageheader' => 'Add New Parent Menu',
            'subheader' => '',
            'data'      => $data,
            'data_menu' => $data_menu
        ]);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {        
        $data = Parentmenu::where('menu_type','parent')->orderBy('id','DESC')->get();
        return view('menu.addparentmenu',[
            'title'      => 'Add Parent Menu: RIMS Admin Panel',
            'pageheader' => 'Add New Parent Menu',
            'subheader'  => '',
            'data'       => $data
        ]);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //
        //dd($request->all(), $request->url(), $request->path(),$request->fullUrl(), $request->root(), $request);
        $validator = Validator::make($request->all(), [
            'menuname' => 'required',
            'manu_url' => 'required',            
        ],
        $messages = [
            'menuname.required' => 'Menu name is required!',
            'manu_url.required' => 'Menu route/URL is required!',                       
        ]);

        
        if ($validator->fails()) {            
            return Redirect::back()->withErrors($validator)->withInput();
        }else{

            $parentmenu = new Parentmenu;
            $input      = $request->all();          

            //dd(Auth::user()->id);  

            $parentmenu->menu_name   = $request->input('menuname');
            $parentmenu->menu_url    = $request->input('manu_url');     
            $parentmenu->parent_id   = $request->input('parentmenu');      
            $parentmenu->status      = '1';
            $parentmenu->menu_icon	 = $request->input('manu_icon');
            $parentmenu->created_at  = Carbon::now();
            $parentmenu->added_by    = Auth::user()->id;
            

            if($request->parentmenu == 'No-Parent'){
                //dd('parentmenu is not exists.');
                $parentmenu->menu_type  = 'parent';
                $parentmenu->parent_id  =  '0';
            }else{        
                //dd('parentmenu is not exists.');
                $parentmenu->menu_type = 'child';
            }

            //-------------------------------

            if($request->manu_icon == ''){                
                $parentmenu->menu_icon  = '#';                
            }else{
                $parentmenu->menu_icon  = $request->input('manu_icon');   
            }

            //dd($request->manu_icon, $parentmenu);            
            $parentmenu->save();
            return redirect()->back()->with('success','Admin Menu Added Successfully');
        } 
    }

    /**
     * Display the specified resource.
     */
    public function show(Parentmenu $parentmenu)
    {
        //

    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Parentmenu $parentmenu)
    {
        //
        //dd($parentmenu->id);
        if($parentmenu->id != ''){  
            $data = Parentmenu::where('menu_type','parent')->orderBy('id','DESC')->get();   
            
            //$menu = Parentmenu::where('menu_type','parent')->where('id',$parentmenu->id)->first();
            //dd($menu->menu_name);

            return view('menu.editparentmenu',[
                'title'      => 'Update Admin Menu: RIMS Admin Panel',
                'pageheader' => 'Update Admin Menu',
                'subheader'  => '',
                'data'       => $data,
                'menu_data'  => $parentmenu
            ]);

        }else{
            return redirect()->back()->with('error','Auth error, Data did not match');
        }    
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Parentmenu $parentmenu)
    {

        // $user                 = Parentmenu::find(2); 
        // $parent               = $user->parent; // 4
        // $parent_d             = $user->parentRecursive; // 4
        // $parent_all_parent    = $user->parentRecursiveFlatten;        
        // dd($request->all(), $request->url(), $request->path(),$request->fullUrl(), $request->root(), $request);

        $validator = Validator::make($request->all(), [
            'menuname' => 'required',
            'manu_url' => 'required',            
        ],
        $messages = [
            'menuname.required' => 'Menu name is required!',
            'manu_url.required' => 'Menu route/URL is required!',                       
        ]);

        
        if ($validator->fails()) {            
            return Redirect::back()->withErrors($validator)->withInput();
        }else{
                       
            $parentmenu = Parentmenu::find($parentmenu->id);    

            $parentmenu->menu_name   = $request->input('menuname');
            $parentmenu->menu_url    = $request->input('manu_url');
            $parentmenu->parent_id   = $request->input('parentmenu');
            $parentmenu->menu_icon	 = $request->input('manu_icon');
            $parentmenu->status      = $request->input('status');           
            $parentmenu->updated_at  = Carbon::now();
            $parentmenu->added_by    = Auth::user()->id;
            

            if($request->parentmenu == 'No-Parent'){
                //dd('parentmenu is not exists.');
                $parentmenu->menu_type  = 'parent';
                $parentmenu->parent_id  =  '0';
            }else{        
                //dd('parentmenu is not exists.');
                $parentmenu->menu_type = 'child';
            }


            //-------------------------------

            if($request->manu_icon == ''){                
                $parentmenu->menu_icon  = '#';                
            }else{
                $parentmenu->menu_icon  = $request->input('manu_icon');   
            }

            //dd($parentmenu);
            //dd(Auth::user()->id, $parentmenu, $request->all());

            $parentmenu->save();           
            return redirect()->action([ParentmenuController::class, 'index'])->with('success','Admin Menu Updated Successfully');
        } 
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Parentmenu $parentmenu)
    {
        //
        $parentmenu = Parentmenu::find($parentmenu->id);    
        dd($parentmenu);
        $parentmenu->delete();
        return redirect()->back()->with('success','Admin Menu Deleted Successfully');
    }


    public function DeleteParentMenu(Request $request, $id){

        $parentmenu = Parentmenu::find($id);    
        //dd($parentmenu);
        $parentmenu->delete();
        return redirect()->back()->with('success','Admin Menu Deleted Successfully');

    }
}
