<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Response;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;

use Carbon\Carbon;
use Str;
Use Hash;
use Auth;

use App\Models\Role;
use App\Models\User;


class RoleController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        //
        $data       = Role::orderBy('id','DESC')->paginate(10);
        return view('role.role',[
            'title' => 'Admin Role: RIMS Admin Role',
            'pageheader' => 'Add New Admin Role',
            'subheader' => '',
            'data'      => $data,
            'data_menu' => []
        ]);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
       // $data = Parentmenu::where('menu_type','parent')->orderBy('id','DESC')->get();
        return view('role.addrole',[
            'title' => 'Admin Role: RIMS Admin Role',
            'pageheader' => 'Add New Admin Role',
            'subheader'  => '',
            'data'       => $data ?? []
        ]);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //
        $validator = Validator::make($request->all(), [
            'rolename' => 'required',
        ],
        $messages = [
            'rolename.required' => 'Role name is required!',
        ]);

        
        if ($validator->fails()) {            
            return Redirect::back()->withErrors($validator)->withInput();
        }else{

            $role       = new Role;
            $input      = $request->all();          

            //dd(Auth::user()->id);  

            $role->role_name   = $request->input('rolename');            
            $role->status      = '1';
            $role->created_at  = Carbon::now();
            $role->added_by    = Auth::user()->id;          

            //dd($role);            
            $role->save();

            return redirect()->back()->with('success','Admin Role Added Successfully');
        } 
    }

    /**
     * Display the specified resource.
     */
    public function show(Role $role)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Role $role)
    {
        //
        if($role->id != ''){
            $data = Role::where('id',$role->id)->first(); 

            return view('role.editrole',[
                'title'      => 'Update Admin Role : RIMS Admin Panel',
                'pageheader' => 'Update Admin Role',
                'subheader'  => '',
                'data'       => $data,
                'menu_data'  => []
            ]);

        }else{
            return redirect()->back()->with('error','Auth error, Data did not match');
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Role $role)
    {        
        // $user                 = Parentmenu::find(2); 
        // $parent               = $user->parent; // 4
        // $parent_d             = $user->parentRecursive; // 4
        // $parent_all_parent    = $user->parentRecursiveFlatten;  
        // dd($request->all(), $request->url(), $request->path(),$request->fullUrl(), $request->root(), $request);

        $validator = Validator::make($request->all(), [
            'rolename' => 'required',
        ],
        $messages = [
            'rolename.required' => 'role name is required!',
        ]);

        
        if ($validator->fails()) {            
            return Redirect::back()->withErrors($validator)->withInput();
        }else{
                       
            $role              = Role::find($role->id);

            $role->role_name   = $request->input('rolename');           
            $role->status      = $request->input('status');           
            $role->updated_at  = Carbon::now();
            $role->added_by    = Auth::user()->id;            

            $role->save();           
            return redirect()->action([RoleController::class, 'index'])->with('success','Admin Role Updated Successfully');
        } 
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Role $role)
    {
        //
    }

    
    public function DeleteRole(Request $request, $id){

        $role_d = Role::find($id);    
        //dd($parentmenu);
        $role_d->delete();
        return redirect()->back()->with('success','Admin Role Deleted Successfully');

    }

}
