<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Database\Eloquent\SoftDeletes;


class Parentmenu extends Model
{
    use HasFactory, Notifiable;
    use SoftDeletes;


    protected $table = 'admin_menu';


    protected $fillable = [
        'menu_name',
        'menu_url',
        'admin_menu',
        'status',
        'parent_id',
        'menu_type',
        'menu_order',
        'added_by',
        'created_at',
        'updated_at',
    ];


    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];


    public function parent()
    {
        return $this->belongsTo(self::class, 'parent_id');
    }



    public function parentRecursive()
    {
        return $this->parent()->with('parentRecursive');
    }



    public function parentRecursiveFlatten()
    {
        $result = collect();
        $item = $this->parentRecursive;
        if ($item instanceof User) {
            $result->push($item);
            $result = $result->merge($item->parentRecursiveFlatten());
        }
        return $result;
    }


    public function children()
    {
        return $this->hasMany(self::class, 'parent_id');
    }

    

    public function childrenRecursive()
    {
        return $this->children()->with('childrenRecursive');
    }

}
